# More templates for FLM

Install using:
```
> pip install flm-templates
```

This FLM extension package provides a few more elaborate HTML templates.
Perhaps I'll add more in the future.  Feel free to contribute new ones
as well!  The templates provided here use the
[Jinja2 template engine](https://jinja.palletsprojects.com/), which is
significantly more powerful, flexible, and robust than the minimalistic
built-in template engine provided in FLM's core package.
